dnl
dnl pnet_build_env.m4 - Set up the Portable.NET C# build environment.
dnl
dnl Copyright (c) 2002  Southern Storm Software, Pty Ltd.
dnl
dnl This program is free software; you can redistribute it and/or modify
dnl it under the terms of the GNU General Public License as published by
dnl the Free Software Foundation; either version 2 of the License, or
dnl (at your option) any later version.
dnl
dnl This program is distributed in the hope that it will be useful,
dnl but WITHOUT ANY WARRANTY; without even the implied warranty of
dnl MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
dnl GNU General Public License for more details.
dnl
dnl You should have received a copy of the GNU General Public License
dnl along with this program; if not, write to the Free Software
dnl Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
dnl

AC_DEFUN([PNET_BUILD_ENV],[

dnl Make sure that pnet support is initialized.
AC_REQUIRE([PNET_INIT])

dnl Extra substitution variables.
AC_SUBST(CSANT)
AC_SUBST(CSANT_FLAGS)
AC_SUBST(CSHARP_COMPILER)
AC_SUBST(CSDOC)
AC_SUBST(RESGEN)
AC_SUBST(RESGEN_FLAGS)

dnl Find the Portable.NET "csant" program.
AC_PATH_PROG(CSANT, csant,, $PNET_PATH/csant:${prefix}/bin:$PATH)
if test "$CSANT" = "" ; then
	echo '**************************************************************'
	echo "Portable.NET's csant tool is required to build the system."
	echo "Use the --with-pnet option to specify Portable.NET's location."
	echo '**************************************************************'
	exit 1
fi

dnl Find the C# compiler to use: the default test order is cscc, mcs, csc.
if test "$MSTOOLS" = "no"; then
	if test "$MONOTOOLS" = "no"; then
		AC_PATH_PROG(CSHARP_COMPILER, cscc,, $PNET_PATH/cscc:${prefix}/bin:$PATH)
		if test "$CSHARP_COMPILER" = "" ; then
			AC_PATH_PROG(CSHARP_COMPILER, mcs,, ${prefix}/bin:$PATH)
			if test "$CSHARP_COMPILER" = ""; then
				AC_PATH_PROG(CSHARP_COMPILER, csc,, ${prefix}/bin:$PATH)
				if test "$CSHARP_COMPILER" = ""; then
					echo '******************************************************'
					echo "Cannot locate a suitable C# compiler to use.  Use the"
					echo "--with-pnet option to specify the location of the"
					echo "Portable.NET source tree."
					echo '******************************************************'
					exit 1
				else
					CSANT_FLAGS='--compiler csc -Dcsc="$(CSHARP_COMPILER)"'
				fi
			else
				CSANT_FLAGS='--compiler mcs -Dmcs="$(CSHARP_COMPILER)"'
			fi
		else
			CSANT_FLAGS='--compiler cscc -Dcscc="$(top_builddir)/m4/tools/csccwrap.sh"'
		fi
	else
		AC_PATH_PROG(CSHARP_COMPILER, mcs,, ${prefix}/bin:$PATH)
		if test "$CSHARP_COMPILER" = ""; then
			echo '***************************************************'
			echo "Could not locate Mono's C# compiler (mcs)."
			echo '***************************************************'
			exit 1
		fi
		CSANT_FLAGS='--compiler mcs -Dmcs="$(CSHARP_COMPILER)"'
	fi
else
	AC_PATH_PROG(CSHARP_COMPILER, csc,, ${prefix}/bin:$PATH)
	if test "$CSHARP_COMPILER" = ""; then
		echo '***************************************************'
		echo "Could not locate Microsoft's C# compiler (csc.exe)."
		echo '***************************************************'
		exit 1
	fi
	CSANT_FLAGS='--compiler csc -Dcsc="$(CSHARP_COMPILER)"'
fi

dnl Find the version of "csdoc" to use.
if test "$MSTOOLS" = "no" -a "$MONOTOOLS" = "no"; then
	AC_PATH_PROG(CSDOC, csdoc,, $PNET_PATH/cscc:${prefix}/bin:$PATH)
	if test "$CSDOC" = "" ; then
		CSANT_FLAGS="$CSANT_FLAGS --dummy-doc"
	else
		CSANT_FLAGS="$CSANT_FLAGS "'-Dcsdoc="$(top_builddir)/m4/tools/csdocwrap.sh"'
	fi
else
	CSANT_FLAGS="$CSANT_FLAGS --dummy-doc"
fi

dnl Find the .NET resource generator to use.
AC_PATH_PROG(RESGEN, resgen,, $PNET_PATH/resgen:${prefix}/bin:$PATH)
if test "$RESGEN" = "" ; then
	echo '**************************************************************'
	echo "Portable.NET's or Microsoft's resgen is required to build."
	echo "Use the --with-pnet option to specify Portable.NET's location."
	echo '**************************************************************'
	exit 1
fi

dnl Determine which version of RESGEN we are using (Portable.NET or Microsoft).
RESGEN_ERROR=`"$RESGEN" -v.txt 2>&1`
case "$RESGEN_ERROR" in
  RESGEN*) RESGEN_FLAGS="-tR" ;;
        *) RESGEN_FLAGS="" ;;
esac
AM_CONDITIONAL(PNET_RESGEN, test "$RESGEN_FLAGS" != "")

dnl Make sure that our helper scripts are made +x at the end of the process.
AC_OUTPUT_COMMANDS([
chmod +x "./m4/tools/csccwrap.sh"
chmod +x "./m4/tools/csdocwrap.sh"
])

])
