dnl
dnl pnet_init.m4 - Initialize the Portable.NET environment for autoconf.
dnl
dnl Copyright (c) 2002  Southern Storm Software, Pty Ltd.
dnl
dnl This program is free software; you can redistribute it and/or modify
dnl it under the terms of the GNU General Public License as published by
dnl the Free Software Foundation; either version 2 of the License, or
dnl (at your option) any later version.
dnl
dnl This program is distributed in the hope that it will be useful,
dnl but WITHOUT ANY WARRANTY; without even the implied warranty of
dnl MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
dnl GNU General Public License for more details.
dnl
dnl You should have received a copy of the GNU General Public License
dnl along with this program; if not, write to the Free Software
dnl Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
dnl
dnl The PNET_INIT autoconf macro sets everything up to use Portable.NET
dnl to build or run applications.
dnl
dnl The following options are added to configure.in's command-line:
dnl
dnl		--with-pnet=DIR
dnl			Specify the location of the Portable.NET source tree.
dnl			This is used to support builds on systems that have
dnl			not done a "make install" on pnet.
dnl
dnl		--with-mstools
dnl			Use the Microsoft C# compiler instead of Portable.NET's cscc.
dnl			You still need Portable.NET for csant, csdoc, ilrun, etc.
dnl
dnl		--with-mono
dnl			Use the Mono C# compiler instead of Portable.NET's cscc.
dnl			You still need Portable.NET for csant, csdoc, ilrun, etc.
dnl
dnl		--with-language=LANG
dnl			Specify the language to use for string resources.  The
dnl			default is determined from the "LANG" environment variable,
dnl			with "en_US" being the ultimate fallback.
dnl

AC_DEFUN([PNET_INIT], [

dnl Extra substitution variables.
AC_SUBST(PNET_PATH)
AC_SUBST(PNET_LANGUAGE)

dnl The --with-pnet option can be used to specify the location of
dnl Portable.NET, so that we know where to get the C# compiler, etc.
dnl The default location is assumed to be "../pnet".
AC_ARG_WITH(pnet,
[  --with-pnet=DIR         specify the location of Portable.NET],
[
	if test -n "$withval"; then
		case "$withval" in
		  ../*) PNET_PATH="`pwd`/$withval" ;;
		     *) PNET_PATH="$withval" ;;
		esac
	else
		PNET_PATH="`pwd`/../pnet"
	fi
],
[
	PNET_PATH="`pwd`/../pnet"
])

dnl The --with-mstools option can be used to force the use of
dnl Microsoft's toolchain instead of Portable.NET's.
AC_ARG_WITH(mstools,
[  --with-mstools          use Microsoft tools instead of Portable.NET's],
[
	MSTOOLS=yes
],
[
	MSTOOLS=no
])

dnl The --with-mono option can be used to force the use of
dnl Mono's toolchain instead of Portable.NET's.
AC_ARG_WITH(mono,
[  --with-mono             use Mono tools instead of Portable.NET's],
[
	MONOTOOLS=yes
],
[
	MONOTOOLS=no
])

dnl The --with-language option can be used to specify the language
dnl for string resources.
AC_ARG_WITH(language,
[  --with-language=LANG    specify the string resource language],
[
	if test -n "$withval"; then
		if test -d "${srcdir}/resources/$withval" ; then
			PNET_LANGUAGE="$withval"
		else
			AC_MSG_ERROR([unknown resource language ${withval}])
		fi
	else
		if test -n "$LANG" -a -d "${srcdir}/resources/$LANG" ; then
			PNET_LANGUAGE="$LANG"
		else
			PNET_LANGUAGE=en_US
		fi
	fi
],
[
	if test -n "$LANG" -a -d "${srcdir}/resources/$LANG" ; then
		PNET_LANGUAGE="$LANG"
	else
		PNET_LANGUAGE=en_US
	fi
])

])
